@@ -115,7 +115,9 @@ void FileTypeDialog::slotDatabaseChanged(const QStringList &changedResources)
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-filetype-association")));
 
     KAboutData aboutData(QStringLiteral("keditfiletype"),
