@@ -8,11 +8,11 @@
 #include "mimetypedata.h"
 #include "mimetypewriter.h"
 #include <KApplicationTrader>
+#include <KParts/PartLoader>
 #include <QFileInfo>
 #include <QStandardPaths>
 #include <QXmlStreamReader>
 #include <kconfiggroup.h>
-#include <kmimetypetrader.h>
 #include <kprotocolmanager.h>
 #include <kservice.h>
 #include <ksharedconfig.h>
@@ -95,10 +95,9 @@ void MimeTypeData::initFromQMimeType()
         }
     }
 
-    QListIterator<QString> mimeFilesIter(mimeFiles);
-    mimeFilesIter.toBack();
-    while (mimeFilesIter.hasPrevious()) { // global first, then local.
-        const QString fullPath = mimeFilesIter.previous();
+    // Reverse iterator to get global first, then local.
+    for (auto rIt = mimeFiles.crbegin(); rIt != mimeFiles.crend(); ++rIt) {
+        const QString fullPath = *rIt;
         QFile qfile(fullPath);
         if (!qfile.open(QFile::ReadOnly)) {
             continue;
@@ -118,7 +117,7 @@ void MimeTypeData::initFromQMimeType()
             }
 
             while (xml.readNextStartElement()) {
-                const QStringRef tag = xml.name();
+                const auto tag = xml.name();
                 if (tag == QLatin1String("icon")) {
                     m_userSpecifiedIcon = xml.attributes().value(QLatin1String("name")).toString();
                 }
@@ -212,23 +211,22 @@ void MimeTypeData::setUserSpecifiedIcon(const QString &icon)
 
 QStringList MimeTypeData::getAppOffers() const
 {
-    QStringList services;
+    QStringList serviceIds;
     const KService::List offerList = KApplicationTrader::queryByMimeType(name());
-    KService::List::const_iterator it(offerList.begin());
-    for (; it != offerList.constEnd(); ++it) {
-        services.append((*it)->storageId());
+    for (const auto &servicePtr : offerList) {
+        serviceIds.append(servicePtr->storageId());
     }
-    return services;
+    return serviceIds;
 }
 
 QStringList MimeTypeData::getPartOffers() const
 {
-    QStringList services;
-    const KService::List partOfferList = KMimeTypeTrader::self()->query(name(), QStringLiteral("KParts/ReadOnlyPart"));
-    for (KService::List::const_iterator it = partOfferList.begin(); it != partOfferList.constEnd(); ++it) {
-        services.append((*it)->storageId());
+    QStringList servicesIds;
+    const auto partOfferList = KParts::PartLoader::partsForMimeType(name());
+    for (const auto &metaData : partOfferList) {
+        servicesIds.append(metaData.pluginId());
     }
-    return services;
+    return servicesIds;
 }
 
 void MimeTypeData::getMyServiceOffers() const
@@ -425,18 +423,19 @@ void MimeTypeData::syncServices()
 
 static QStringList collectStorageIds(const QStringList &services)
 {
-    QStringList serviceList;
-    QStringList::const_iterator it(services.begin());
-    for (int i = services.count(); it != services.end(); ++it, i--) {
-        KService::Ptr pService = KService::serviceByStorageId(*it);
+    QStringList storageIds;
+
+    for (const QString &service : services) {
+        KService::Ptr pService = KService::serviceByStorageId(service);
         if (!pService) {
-            qWarning() << "service with storage id" << *it << "not found";
+            qWarning() << "service with storage id" << service << "not found";
             continue; // Where did that one go?
         }
 
-        serviceList.append(pService->storageId());
+        storageIds.append(pService->storageId());
     }
-    return serviceList;
+
+    return storageIds;
 }
 
 void MimeTypeData::saveRemovedServices(KConfigGroup &config, const QStringList &services, const QStringList &oldServices)
@@ -473,8 +472,12 @@ void MimeTypeData::saveDefaultApplication(KConfigGroup &config, const QStringLis
 {
     if (services.isEmpty()) {
         config.deleteEntry(name());
-    } else {
-        const QString firstStorageId = collectStorageIds(services).first();
+        return;
+    }
+
+    const QStringList storageIds = collectStorageIds(services);
+    if (!storageIds.isEmpty()) {
+        const QString firstStorageId = storageIds.at(0);
         config.writeXdgListEntry(name(), {firstStorageId});
     }
 }
